==> s390-tools_1.3.1.orig.tar.gz: s390-tools_1.3.1.orig/qetharp/qetharp26.h <==
/*
 * File...........: qetharp26.c
 * Author(s)......: Thomas Spatzier <tspat@de.ibm.com>
 *                  (adaptations to 2.6 kernel)
 * originally written by: Frank Pavlic <pavlic@de.ibm.com>
 * 
 * Bugreports.to..: <Linux390@de.ibm.com>
 * (C) IBM Corporation 2001,2004
 *
 */
#ifndef __QETHARP_26_H__
#define __QETHARP_26_H__

#include <linux/types.h>
#include <linux/if.h>
#include "qeth26.h"

#define ifr_name	ifr_ifrn.ifrn_name	/* interface name 	*/
#define ifr_hwaddr	ifr_ifru.ifru_hwaddr	/* MAC address 		*/
#define	ifr_addr	ifr_ifru.ifru_addr	/* address		*/
#define	ifr_dstaddr	ifr_ifru.ifru_dstaddr	/* other end of p-p lnk	*/
#define	ifr_broadaddr	ifr_ifru.ifru_broadaddr	/* broadcast address	*/
#define	ifr_netmask	ifr_ifru.ifru_netmask	/* interface net mask	*/
#define	ifr_flags	ifr_ifru.ifru_flags	/* flags		*/
#define	ifr_metric	ifr_ifru.ifru_ivalue	/* metric		*/
#define	ifr_mtu		ifr_ifru.ifru_mtu	/* mtu			*/
#define ifr_map		ifr_ifru.ifru_map	/* device map		*/
#define ifr_slave	ifr_ifru.ifru_slave	/* slave device		*/
#define	ifr_data	ifr_ifru.ifru_data	/* for use by interface	*/
#define ifr_ifindex	ifr_ifru.ifru_ivalue	/* interface index	*/
#define ifr_bandwidth	ifr_ifru.ifru_ivalue    /* link bandwidth	*/
#define ifr_qlen	ifr_ifru.ifru_ivalue	/* Queue length 	*/
#define ifr_newname	ifr_ifru.ifru_newname	/* New name		*/


/*****************************************************
 *    Declarations for OSA Relevant Things           *
 *****************************************************/


#define DATA_SIZE 20000
#define HIPERSOCKET_FLAGS  5
#define OSACARD_FLAGS      7
#define OSA_TR_FLAGS       0xf

#define MAC_LENGTH             6
#define IPV4_LENGTH            4
#define IPV6_LENGTH            16
#define IP_VERSION_4           1

/*****************************************************
 *            Declarations for parsing options       *
 *****************************************************/

#define QETHARP_GETOPT_STRING "p:q:a:d:i:m:nchv"

#define OPTION_INFO_QUERY              1
#define OPTION_INFO_PURGE              1
#define OPTION_INFO_HOST_RESOLUTION    1
#define OPTION_INFO_COMPACT_OUTPUT     1
#define OPTION_INFO_ADD                1
#define OPTION_INFO_DELETE             1
#define OPTION_INFO_IP                 1
#define OPTION_INFO_MAC                1


static struct option qetharp_options[]=
{
	{ "query",        1, 0, 'q'},  
	{ "purge",        1, 0, 'p'},
	{ "numeric",      0, 0, 'n'},
	{ "compact",      0, 0, 'c'},
	{ "add",          1, 0, 'a'},
	{ "delete",       1, 0, 'd'},
	{ "ip",           1, 0, 'i'},
	{ "mac",          1, 0, 'm'},
	{ "help",         0, 0, 'h'},
	{ "version",      0, 0, 'v'},
	{0,0,0,0}
};

struct option_info {
	int purge_flag;
	int query_flag;
	int host_resolution;
	int compact_output;
	int add_flag;
	int delete_flag;
	int ip_flag;
	int mac_flag;
	char *dev_name;
	char *ip_addr;
	char *mac_addr;
};

#endif /* __QETHARP_26_H__ */

==> s390-tools_1.5.3.orig.tar.gz: s390-tools-1.5.3.orig/qetharp/qetharp26.h <==
/*
 * File...........: qetharp26.c
 * Author(s)......: Thomas Spatzier <tspat@de.ibm.com>
 *                  (adaptations to 2.6 kernel)
 * originally written by: Frank Pavlic <pavlic@de.ibm.com>
 * 
 * Bugreports.to..: <Linux390@de.ibm.com>
 * (C) IBM Corporation 2001,2004
 *
 */
#ifndef __QETHARP_26_H__
#define __QETHARP_26_H__

#include <linux/types.h>
#include <linux/if.h>
#include "qeth26.h"

#define ifr_name	ifr_ifrn.ifrn_name	/* interface name 	*/
#define ifr_hwaddr	ifr_ifru.ifru_hwaddr	/* MAC address 		*/
#define	ifr_addr	ifr_ifru.ifru_addr	/* address		*/
#define	ifr_dstaddr	ifr_ifru.ifru_dstaddr	/* other end of p-p lnk	*/
#define	ifr_broadaddr	ifr_ifru.ifru_broadaddr	/* broadcast address	*/
#define	ifr_netmask	ifr_ifru.ifru_netmask	/* interface net mask	*/
#define	ifr_flags	ifr_ifru.ifru_flags	/* flags		*/
#define	ifr_metric	ifr_ifru.ifru_ivalue	/* metric		*/
#define	ifr_mtu		ifr_ifru.ifru_mtu	/* mtu			*/
#define ifr_map		ifr_ifru.ifru_map	/* device map		*/
#define ifr_slave	ifr_ifru.ifru_slave	/* slave device		*/
#define	ifr_data	ifr_ifru.ifru_data	/* for use by interface	*/
#define ifr_ifindex	ifr_ifru.ifru_ivalue	/* interface index	*/
#define ifr_bandwidth	ifr_ifru.ifru_ivalue    /* link bandwidth	*/
#define ifr_qlen	ifr_ifru.ifru_ivalue	/* Queue length 	*/
#define ifr_newname	ifr_ifru.ifru_newname	/* New name		*/


/*****************************************************
 *    Declarations for OSA Relevant Things           *
 *****************************************************/


#define DATA_SIZE 20000
#define HIPERSOCKET_FLAGS  5
#define OSACARD_FLAGS      7
#define OSA_TR_FLAGS       0xf

#define MAC_LENGTH             6
#define IPV4_LENGTH            4
#define IPV6_LENGTH            16
#define IP_VERSION_4           1

/*****************************************************
 *            Declarations for parsing options       *
 *****************************************************/

#define QETHARP_GETOPT_STRING "p:q:a:d:i:m:nchv"

#define OPTION_INFO_QUERY              1
#define OPTION_INFO_PURGE              1
#define OPTION_INFO_HOST_RESOLUTION    1
#define OPTION_INFO_COMPACT_OUTPUT     1
#define OPTION_INFO_ADD                1
#define OPTION_INFO_DELETE             1
#define OPTION_INFO_IP                 1
#define OPTION_INFO_MAC                1

/*****************************************************
 *            Declarations for version string        *
 *****************************************************/
#define VERSION_NO "0.02"
#define COPYRIGHT "\(C) Copyright IBM Corp. 2003-2004\n\n"
#define STRINGIFY_1(x)   #x
#define STRINGIFY(x)     STRINGIFY_1(x)
#define RELEASE_STRING   STRINGIFY (S390_TOOLS_RELEASE)

static struct option qetharp_options[]=
{
	{ "query",        1, 0, 'q'},  
	{ "purge",        1, 0, 'p'},
	{ "numeric",      0, 0, 'n'},
	{ "compact",      0, 0, 'c'},
	{ "add",          1, 0, 'a'},
	{ "delete",       1, 0, 'd'},
	{ "ip",           1, 0, 'i'},
	{ "mac",          1, 0, 'm'},
	{ "help",         0, 0, 'h'},
	{ "version",      0, 0, 'v'},
	{0,0,0,0}
};

struct option_info {
	int purge_flag;
	int query_flag;
	int host_resolution;
	int compact_output;
	int add_flag;
	int delete_flag;
	int ip_flag;
	int mac_flag;
	char *dev_name;
	char *ip_addr;
	char *mac_addr;
};

#endif /* __QETHARP_26_H__ */
